@@ -359,7 +359,7 @@ def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
     if data_type in v4c.NON_SCALAR_TYPES:
         size = size // 8
 
-        if data_type == v4c.DATA_TYPE_BYTEARRAY:
+        if data_type in (v4c.DATA_TYPE_BYTEARRAY, v4c.DATA_TYPE_MIME_STREAM, v4c.DATA_TYPE_MIME_SAMPLE):
             if channel_type == v4c.CHANNEL_TYPE_VALUE:
                 fmt = f"({size},)u1"
             else:
@@ -1017,6 +1017,12 @@ class Group:
     def __contains__(self, item):
         return hasattr(self, item)
 
+    def clear(self):
+        self.data_blocks.clear()
+        self.channels.clear()
+        self.channel_dependencies.clear()
+        self.signal_data.clear()
+
 
 class VirtualChannelGroup:
     """ starting with MDF v4.20 it is possible to use remote masters and column
@@ -1693,10 +1699,20 @@ def all_blocks_addresses(obj):
         pass
 
     try:
-        match_starts = [match.start() for match in re.finditer(pattern, obj)]
+        re.search(pattern, obj)
+        source = obj
     except TypeError:
-        """ TypeError: expected string or bytes-like object when reading
-        PyFilesystem concrete class from S3.
-        """
-        match_starts = [match.start() for match in re.finditer(pattern, obj.read())]
-    return match_starts
+        source = obj.read()
+
+    addresses = []
+    blocks = {}
+
+    for match in re.finditer(pattern, source):
+        btype = match.group('block')
+        start = match.start()
+
+        btype_addresses = blocks.setdefault(btype, [])
+        btype_addresses.append(start)
+        addresses.append(start)
+
+    return blocks, addresses
