@@ -49,6 +49,8 @@ DATA_TYPE_TO_STRING = dict(
 
 NON_SCALAR_TYPES = {
     DATA_TYPE_BYTEARRAY,
+    DATA_TYPE_MIME_SAMPLE,
+    DATA_TYPE_MIME_STREAM,
     DATA_TYPE_STRING_UTF_8,
     DATA_TYPE_STRING_LATIN_1,
     DATA_TYPE_STRING_UTF_16_BE,
@@ -315,6 +317,14 @@ FLAG_CG_PLAIN_BUS_EVENT = 1 << 2
 FLAG_CG_REMOTE_MASTER = 1 << 3
 FLAG_CG_EVENT_GROUP = 1 << 4
 
+FLAG_UNFIN_UPDATE_CG_COUNTER = 0x1
+FLAG_UNFIN_UPDATE_SR_COUNTER = 0x2
+FLAG_UNFIN_UPDATE_LAST_DT_LENGTH = 0x4
+FLAG_UNFIN_UPDATE_LAST_RD_LENGTH = 0x8
+FLAG_UNFIN_UPDATE_LAST_DL = 0x10
+FLAG_UNFIN_UPDATE_VLSD_BYTES = 0x20
+FLAG_UNFIN_UPDATE_VLSD_OFFSETS = 0x40
+
 FLAG_CG_TO_STRING = {
     FLAG_CG_VLSD: "VLSD",
     FLAG_CG_BUS_EVENT: "BUS_EVENT",
@@ -536,7 +546,7 @@ COMMON_SHORT_u = struct.Struct(FMT_COMMON_SHORT).unpack
 COMMON_SHORT_uf = struct.Struct(FMT_COMMON_SHORT).unpack_from
 COMMON_SHORT_p = struct.Struct(FMT_COMMON_SHORT).pack
 
-FMT_FILE_HISTORY = "<4sI5Q2HB3s"
+FMT_FILE_HISTORY = "<4sI5Q2hB3s"
 KEYS_FILE_HISTORY = (
     "id",
     "reserved0",
@@ -630,7 +640,7 @@ FMT_CONVERSION_RAT_INIT = "<4Q2B3H8d"
 
 FMT_CONVERSION_RAT_INIT = "<4Q2B3H8d"
 
-FMT_HEADER_BLOCK = "<4sI9Q2H4B2Q"
+FMT_HEADER_BLOCK = "<4sI9Q2h4B2Q"
 FMT_IDENTIFICATION_BLOCK = "<8s8s8s4sH30s2H"
 
 KEYS_HEADER_BLOCK = (
@@ -718,7 +728,7 @@ KEYS_HL_BLOCK = (
 )
 
 FMT_EVENT_PARAMS = "<5B3sI2HQd"
-FMT_EVENT = "<4sI2Q{}Q5B3sI2HQd"
+FMT_EVENT = "<4sI2Q{}Q5B3sI2Hqd"
 
 FMT_SR_BLOCK = "<4sI5Qd2B6s"
 KEYS_SR_BLOCK = (
