@@ -1,15 +1,12 @@
 # -*- coding: utf-8 -*-
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
-from PyQt5 import QtCore
+from PyQt5 import QtCore, QtGui, QtWidgets
 
 from ..ui import resource_rc as resource_rc
-
 from ..widgets.channel_group_info import ChannelGroupInfoWidget
 
 
 class ChannelGroupInfoDialog(QtWidgets.QDialog):
-    def __init__(self, channel_group, index, *args, **kwargs):
+    def __init__(self, mdf, group, index, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         self.setWindowFlags(QtCore.Qt.Window)
@@ -19,7 +16,7 @@ class ChannelGroupInfoDialog(QtWidgets.QDialog):
 
         self.setWindowTitle(f"Channel group {index}")
 
-        layout.addWidget(ChannelGroupInfoWidget(channel_group, self))
+        layout.addWidget(ChannelGroupInfoWidget(mdf, group, self))
 
         self.setStyleSheet('font: 8pt "Consolas";}')
 
