@@ -11,10 +11,6 @@ from PyQt5 import QtCore, QtGui, QtWidgets
 
 from ...blocks import v4_constants as v4c
 from ...blocks.utils import csv_bytearray2hex, extract_cncomment_xml, MdfException
-from ...blocks.v4_constants import FLAG_CG_BUS_EVENT
-from ...mdf import MDF, SUPPORTED_VERSIONS
-from ...signal import Signal
-from ..dialogs.channel_group_info import ChannelGroupInfoDialog
 from ..dialogs.channel_info import ChannelInfoDialog
 from ..utils import (
     add_children,
@@ -30,7 +26,6 @@ from ..utils import (
 )
 from .numeric import Numeric
 from .plot import Plot
-from .search import SearchWidget
 from .tabular import Tabular
 from .tree import TreeWidget
 
@@ -109,34 +104,65 @@ class WithMDIArea:
 
     def add_new_channels(self, names, widget):
         try:
-            # name is tuple (channel_name, group_index, channel_index, mdf_uuid)
-            signals_ = [name[:3] for name in names if name[1:3] != (-1, -1)]
 
-            computed = [json.loads(name[0]) for name in names if name[1:3] == (-1, -1)]
+            signals_ = [name for name in names if name[1:] != (-1, -1)]
 
-            sigs = self.mdf.select(
-                signals_, copy_master=False, validate=True, raw=True,
-            )
+            computed = [json.loads(name[0]) for name in names if name[1:] == (-1, -1)]
 
-            for sig in sigs:
-                group, index = self.mdf.whereis(sig.name)[0]
-                sig.group_index = group
-                sig.channel_index = index
-                sig.computed = False
-                sig.computation = {}
-                sig.mdf_uuid = self.uuid
+            uuids = set(entry[3] for entry in signals_)
+
+            signals = []
+
+            for uuid in uuids:
+                uuids_signals = [entry[:3] for entry in signals_ if entry[3] == uuid]
+
+                file_info = self.file_by_uuid(uuid)
+                if not file_info:
+                    continue
+
+                file_index, file = file_info
+
+                selected_signals = file.mdf.select(
+                    uuids_signals,
+                    ignore_value2text_conversions=self.ignore_value2text_conversions,
+                    copy_master=False,
+                    validate=True,
+                    raw=True,
+                )
+
+                for sig, sig_ in zip(selected_signals, uuids_signals):
+                    sig.group_index = sig_[1]
+                    sig.channel_index = sig_[2]
+                    sig.computed = False
+                    sig.computation = {}
+                    sig.mdf_uuid = uuid
+
+                    if not hasattr(self, "mdf"):
+                        # MainWindow => comparison plots
+
+                        sig.tooltip = f"{sig.name}\n@ {file.file_name}"
+                        sig.name = f"{file_index+1}: {sig.name}"
+
+                signals.extend(selected_signals)
 
             if isinstance(widget, Plot):
-
-                sigs = [
+                signals = [
                     sig
-                    for sig in sigs
-                    if not sig.samples.dtype.names and len(sig.samples.shape) <= 1
+                    for sig in signals
+                    if sig.samples.dtype.kind not in "SU"
+                    and not sig.samples.dtype.names
+                    and not len(sig.samples.shape) > 1
                 ]
 
-                count = len(widget.plot.signals)
-                for i, sig in enumerate(sigs, count):
-                    sig.color = COLORS[i % len(COLORS)]
+            for signal in signals:
+                if len(signal.samples.shape) > 1:
+
+                    signal.samples = csv_bytearray2hex(pd.Series(list(signal.samples)))
+
+                if signal.name.endswith("CAN_DataFrame.ID"):
+                    signal.samples = signal.samples.astype("<u4") & 0x1FFFFFFF
+
+            signals = sigs = natsorted(signals, key=lambda x: x.name)
 
             widget.add_new_channels(sigs)
 
@@ -575,6 +601,8 @@ class WithMDIArea:
 
     def load_window(self, window_info):
 
+        uuid = self.uuid
+
         if window_info["type"] == "Numeric":
             fmt = window_info["configuration"]["format"]
 
@@ -597,6 +625,7 @@ class WithMDIArea:
 
             for sig, sig_ in zip(signals, signals_):
                 sig.group_index = sig_[1]
+                sig.mdf_uuid = uuid
 
             signals = [
                 sig
@@ -681,6 +710,7 @@ class WithMDIArea:
                 signal.color = channel["color"]
                 signal.group_index = entry_info[1]
                 signal.channel_index = entry_info[2]
+                signal.mdf_uuid = uuid
 
             if measured_signals:
                 all_timebase = np.unique(
@@ -735,6 +765,7 @@ class WithMDIArea:
                     signal.unit = channel["unit"]
                     signal.group_index = -1
                     signal.channel_index = -1
+                    signal.mdf_uuid = uuid
 
                     computed_signals[signal.name] = signal
                 except:
