@@ -1,10 +1,11 @@
 #!/usr/bin/env python
-import unittest
+from pathlib import Path
 import struct
 import tempfile
-from pathlib import Path
+import unittest
 
 import numpy as np
+
 from asammdf import MDF, Signal
 import asammdf.blocks.v2_v3_constants as v23c
 import asammdf.blocks.v4_constants as v4c
@@ -19,91 +20,63 @@ class TestEndianess(unittest.TestCase):
 
     def test_mixed(self):
 
-        t = np.arange(15, dtype='<f8')
+        t = np.arange(15, dtype="<f8")
 
         s1 = Signal(
-            np.frombuffer(b'\x00\x00\x00\x02' * 15, dtype='>u4'),
-            t,
-            name='Motorola'
+            np.frombuffer(b"\x00\x00\x00\x02" * 15, dtype=">u4"), t, name="Motorola"
         )
 
         s2 = Signal(
-            np.frombuffer(b'\x04\x00\x00\x00' * 15, dtype='<u4'),
-            t,
-            name='Intel'
+            np.frombuffer(b"\x04\x00\x00\x00" * 15, dtype="<u4"), t, name="Intel"
         )
 
-        for version in ('3.30', '4.10'):
+        for version in ("3.30", "4.10"):
             mdf = MDF(version=version)
             mdf.append([s1, s2], common_timebase=True)
             outfile = mdf.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
             mdf.close()
 
             with MDF(outfile) as mdf:
-                self.assertTrue(
-                    np.array_equal(
-                        mdf.get('Motorola').samples, [2,] * 15
-                    )
-                )
-                self.assertTrue(
-                    np.array_equal(
-                        mdf.get('Intel').samples, [4,] * 15
-                    )
-                )
+                self.assertTrue(np.array_equal(mdf.get("Motorola").samples, [2,] * 15))
+                self.assertTrue(np.array_equal(mdf.get("Intel").samples, [4,] * 15))
 
-        for version in ('3.30', '4.10'):
+        for version in ("3.30", "4.10"):
             mdf = MDF(version=version)
             mdf.append([s2, s1], common_timebase=True)
             outfile = mdf.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
             mdf.close()
 
             with MDF(outfile) as mdf:
-                self.assertTrue(
-                    np.array_equal(
-                        mdf.get('Motorola').samples, [2,] * 15
-                    )
-                )
-                self.assertTrue(
-                    np.array_equal(
-                        mdf.get('Intel').samples, [4,] * 15
-                    )
-                )
+                self.assertTrue(np.array_equal(mdf.get("Motorola").samples, [2,] * 15))
+                self.assertTrue(np.array_equal(mdf.get("Intel").samples, [4,] * 15))
 
     def test_not_aligned_mdf_v3(self):
 
-        t = np.arange(15, dtype='<f8')
+        t = np.arange(15, dtype="<f8")
 
         s1 = Signal(
-            np.frombuffer(b'\x00\x00\x3F\x02' * 15, dtype='>u4'),
-            t,
-            name='Motorola'
+            np.frombuffer(b"\x00\x00\x3F\x02" * 15, dtype=">u4"), t, name="Motorola"
         )
 
         s2 = Signal(
-            np.frombuffer(b'\x04\xF8\x00\x00' * 15, dtype='<u4'),
-            t,
-            name='Intel'
+            np.frombuffer(b"\x04\xF8\x00\x00" * 15, dtype="<u4"), t, name="Intel"
         )
 
         s3 = Signal(
-            np.frombuffer(b'\xBB\x55' * 2 * 15, dtype='<u4'),
+            np.frombuffer(b"\xBB\x55" * 2 * 15, dtype="<u4"),
             t,
-            name='NotAlignedMotorola'
+            name="NotAlignedMotorola",
         )
 
         s4 = Signal(
-            np.frombuffer(b'\xBB\x55' * 2 * 15, dtype='<u4'),
-            t,
-            name='NotAlignedIntel'
+            np.frombuffer(b"\xBB\x55" * 2 * 15, dtype="<u4"), t, name="NotAlignedIntel"
         )
 
-        with MDF(version='3.30') as mdf_source:
+        with MDF(version="3.30") as mdf_source:
             mdf_source.append([s1, s2, s3, s4], common_timebase=True)
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -117,21 +90,18 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_count = 16
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [0x0204,] * 15
+                        mdf.get("NotAlignedMotorola").samples, [0x0204,] * 15
                     )
                 )
 
                 self.assertTrue(
-                    np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [0x0402,] * 15
-                    )
+                    np.array_equal(mdf.get("NotAlignedIntel").samples, [0x0402,] * 15)
                 )
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -145,20 +115,17 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_count = 24
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [0x3F0204,] * 15
+                        mdf.get("NotAlignedMotorola").samples, [0x3F0204,] * 15
                     )
                 )
                 self.assertTrue(
-                    np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [0x04023F,] * 15
-                    )
+                    np.array_equal(mdf.get("NotAlignedIntel").samples, [0x04023F,] * 15)
                 )
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -172,51 +139,46 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_count = 21
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [(0x3F0204F8 >> 5) & (2**21 - 1),] * 15
+                        mdf.get("NotAlignedMotorola").samples,
+                        [(0x3F0204F8 >> 5) & (2 ** 21 - 1),] * 15,
                     )
                 )
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [(0xF8040200 >> 6) & (2**21 - 1),] * 15
+                        mdf.get("NotAlignedIntel").samples,
+                        [(0xF8040200 >> 6) & (2 ** 21 - 1),] * 15,
                     )
                 )
 
     def test_not_aligned_mdf_v4(self):
 
-        t = np.arange(15, dtype='<f8')
+        t = np.arange(15, dtype="<f8")
 
         s1 = Signal(
-            np.frombuffer(b'\x00\x00\x3F\x02' * 15, dtype='>u4'),
-            t,
-            name='Motorola'
+            np.frombuffer(b"\x00\x00\x3F\x02" * 15, dtype=">u4"), t, name="Motorola"
         )
 
         s2 = Signal(
-            np.frombuffer(b'\x04\xF8\x00\x00' * 15, dtype='<u4'),
-            t,
-            name='Intel'
+            np.frombuffer(b"\x04\xF8\x00\x00" * 15, dtype="<u4"), t, name="Intel"
         )
 
         s3 = Signal(
-            np.frombuffer(b'\xBB\x55' * 2 * 15, dtype='<u4'),
+            np.frombuffer(b"\xBB\x55" * 2 * 15, dtype="<u4"),
             t,
-            name='NotAlignedMotorola'
+            name="NotAlignedMotorola",
         )
 
         s4 = Signal(
-            np.frombuffer(b'\xBB\x55' * 2 * 15, dtype='<u4'),
-            t,
-            name='NotAlignedIntel'
+            np.frombuffer(b"\xBB\x55" * 2 * 15, dtype="<u4"), t, name="NotAlignedIntel"
         )
 
-        with MDF(version='4.11') as mdf_source:
+        with MDF(version="4.11") as mdf_source:
             mdf_source.append([s1, s2, s3, s4], common_timebase=True)
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -230,21 +192,18 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_count = 16
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [0x0204,] * 15
+                        mdf.get("NotAlignedMotorola").samples, [0x0204,] * 15
                     )
                 )
 
                 self.assertTrue(
-                    np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [0x0402,] * 15
-                    )
+                    np.array_equal(mdf.get("NotAlignedIntel").samples, [0x0402,] * 15)
                 )
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -258,20 +217,17 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_count = 24
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [0x3F0204,] * 15
+                        mdf.get("NotAlignedMotorola").samples, [0x3F0204,] * 15
                     )
                 )
                 self.assertTrue(
-                    np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [0x04023F,] * 15
-                    )
+                    np.array_equal(mdf.get("NotAlignedIntel").samples, [0x04023F,] * 15)
                 )
 
             ch3 = mdf_source.groups[0].channels[3]
@@ -287,45 +243,46 @@ class TestEndianess(unittest.TestCase):
             ch4.bit_offset = 6
 
             outfile = mdf_source.save(
-                Path(TestEndianess.tempdir.name) / f"out",
-                overwrite=True,
+                Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
             )
 
             with MDF(outfile) as mdf:
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedMotorola').samples, [(0x3F0204F8 >> 5) & (2**21 - 1),] * 15
+                        mdf.get("NotAlignedMotorola").samples,
+                        [(0x3F0204F8 >> 5) & (2 ** 21 - 1),] * 15,
                     )
                 )
                 self.assertTrue(
                     np.array_equal(
-                        mdf.get('NotAlignedIntel').samples, [(0xF8040200 >> 6) & (2**21 - 1),] * 15
+                        mdf.get("NotAlignedIntel").samples,
+                        [(0xF8040200 >> 6) & (2 ** 21 - 1),] * 15,
                     )
                 )
 
     def test_overlapping_channels_mdf_v3(self):
 
-        t = np.arange(15, dtype='<f8')
+        t = np.arange(15, dtype="<f8")
 
         s1 = Signal(
-            np.frombuffer(b'\x00\x00\x3F\x02\x04\xF8\x00\x00' * 15, dtype='<u8'),
+            np.frombuffer(b"\x00\x00\x3F\x02\x04\xF8\x00\x00" * 15, dtype="<u8"),
             t,
-            name='Parent'
+            name="Parent",
         )
 
         s2 = Signal(
-            np.frombuffer(b'\x04\xF8\x00\x00' * 15, dtype='<u4'),
+            np.frombuffer(b"\x04\xF8\x00\x00" * 15, dtype="<u4"),
             t,
-            name='OverlappingMotorola'
+            name="OverlappingMotorola",
         )
 
         s3 = Signal(
-            np.frombuffer(b'\x04\x00\x00\x00' * 15, dtype='<u4'),
+            np.frombuffer(b"\x04\x00\x00\x00" * 15, dtype="<u4"),
             t,
-            name='OverlappingIntel'
+            name="OverlappingIntel",
         )
 
-        with MDF(version='3.30') as mdf_source:
+        with MDF(version="3.30") as mdf_source:
             mdf_source.append([s1, s2, s3], common_timebase=True)
 
             for parent_data_type in (
@@ -350,20 +307,19 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_count = 16
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [0x0204,] * 15
+                            mdf.get("OverlappingMotorola").samples, [0x0204,] * 15
                         )
                     )
 
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [0x0402,] * 15
+                            mdf.get("OverlappingIntel").samples, [0x0402,] * 15
                         )
                     )
 
@@ -378,19 +334,18 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_count = 24
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [0x3F0204,] * 15
+                            mdf.get("OverlappingMotorola").samples, [0x3F0204,] * 15
                         )
                     )
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [0x04023F,] * 15
+                            mdf.get("OverlappingIntel").samples, [0x04023F,] * 15
                         )
                     )
 
@@ -405,45 +360,46 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_count = 21
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [(0x3F0204F8 >> 5) & (2**21 - 1),] * 15
+                            mdf.get("OverlappingMotorola").samples,
+                            [(0x3F0204F8 >> 5) & (2 ** 21 - 1),] * 15,
                         )
                     )
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [(0xF8040200 >> 6) & (2**21 - 1),] * 15
+                            mdf.get("OverlappingIntel").samples,
+                            [(0xF8040200 >> 6) & (2 ** 21 - 1),] * 15,
                         )
                     )
 
     def test_overlapping_channels_mdf_v4(self):
 
-        t = np.arange(15, dtype='<f8')
+        t = np.arange(15, dtype="<f8")
 
         s1 = Signal(
-            np.frombuffer(b'\x00\x00\x3F\x02\x04\xF8\x00\x00' * 15, dtype='<u8'),
+            np.frombuffer(b"\x00\x00\x3F\x02\x04\xF8\x00\x00" * 15, dtype="<u8"),
             t,
-            name='Parent'
+            name="Parent",
         )
 
         s2 = Signal(
-            np.frombuffer(b'\x04\xF8\x00\x00' * 15, dtype='<u4'),
+            np.frombuffer(b"\x04\xF8\x00\x00" * 15, dtype="<u4"),
             t,
-            name='OverlappingMotorola'
+            name="OverlappingMotorola",
         )
 
         s3 = Signal(
-            np.frombuffer(b'\x04\x00\x00\x00' * 15, dtype='<u4'),
+            np.frombuffer(b"\x04\x00\x00\x00" * 15, dtype="<u4"),
             t,
-            name='OverlappingIntel'
+            name="OverlappingIntel",
         )
 
-        with MDF(version='4.11') as mdf_source:
+        with MDF(version="4.11") as mdf_source:
             mdf_source.append([s1, s2, s3], common_timebase=True)
 
             for parent_data_type in (
@@ -471,20 +427,19 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_offset = 0
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [0x0204,] * 15
+                            mdf.get("OverlappingMotorola").samples, [0x0204,] * 15
                         )
                     )
 
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [0x0402,] * 15
+                            mdf.get("OverlappingIntel").samples, [0x0402,] * 15
                         )
                     )
 
@@ -501,19 +456,18 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_offset = 0
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [0x3F0204,] * 15
+                            mdf.get("OverlappingMotorola").samples, [0x3F0204,] * 15
                         )
                     )
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [0x04023F,] * 15
+                            mdf.get("OverlappingIntel").samples, [0x04023F,] * 15
                         )
                     )
 
@@ -530,19 +484,20 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_offset = 6
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [(0x3F0204F8 >> 5) & (2**21 - 1),] * 15
+                            mdf.get("OverlappingMotorola").samples,
+                            [(0x3F0204F8 >> 5) & (2 ** 21 - 1),] * 15,
                         )
                     )
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [(0xF8040200 >> 6) & (2**21 - 1),] * 15
+                            mdf.get("OverlappingIntel").samples,
+                            [(0xF8040200 >> 6) & (2 ** 21 - 1),] * 15,
                         )
                     )
 
@@ -559,20 +514,17 @@ class TestEndianess(unittest.TestCase):
                 ch4.bit_offset = 1
 
                 outfile = mdf_source.save(
-                    Path(TestEndianess.tempdir.name) / f"out",
-                    overwrite=True,
+                    Path(TestEndianess.tempdir.name) / f"out", overwrite=True,
                 )
 
                 with MDF(outfile) as mdf:
                     self.assertTrue(
                         np.array_equal(
-                            mdf.get('OverlappingMotorola').samples, [0x1] * 15
+                            mdf.get("OverlappingMotorola").samples, [0x1] * 15
                         )
                     )
                     self.assertTrue(
-                        np.array_equal(
-                            mdf.get('OverlappingIntel').samples, [0x1] * 15
-                        )
+                        np.array_equal(mdf.get("OverlappingIntel").samples, [0x1] * 15)
                     )
 
 
